@@ -1,3 +1,5 @@
+use crate::pda::PDA;
+
 use anchor_lang::prelude::*;
 use anchor_lang::AccountDeserialize;
 use std::convert::TryFrom;
@@ -18,3 +20,9 @@ impl TryFrom<Vec<u8>> for Daemon {
         Daemon::try_deserialize(&mut data.as_slice())
     }
 }
+
+impl Daemon {
+    pub fn find_pda(owner: Pubkey) -> PDA {
+        Pubkey::find_program_address(&[SEED_DAEMON, owner.as_ref()], &crate::ID)
+    }
+}
